# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import joint_pb2 as joint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x0bjoint.proto\"J\n\rJointPosition\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x11\n\tpositions\x18\x02 \x03(\x01\"\x19\n\tMatrix4x4\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"8\n\nQuaternion\x12\t\n\x01w\x18\x01 \x01(\x01\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\t\n\x01z\x18\x04 \x01(\x01\x62\x06proto3')



_JOINTPOSITION = DESCRIPTOR.message_types_by_name['JointPosition']
_MATRIX4X4 = DESCRIPTOR.message_types_by_name['Matrix4x4']
_QUATERNION = DESCRIPTOR.message_types_by_name['Quaternion']
JointPosition = _reflection.GeneratedProtocolMessageType('JointPosition', (_message.Message,), {
  'DESCRIPTOR' : _JOINTPOSITION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.JointPosition)
  })
_sym_db.RegisterMessage(JointPosition)

Matrix4x4 = _reflection.GeneratedProtocolMessageType('Matrix4x4', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX4X4,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Matrix4x4)
  })
_sym_db.RegisterMessage(Matrix4x4)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOINTPOSITION._serialized_start=56
  _JOINTPOSITION._serialized_end=130
  _MATRIX4X4._serialized_start=132
  _MATRIX4X4._serialized_end=157
  _QUATERNION._serialized_start=159
  _QUATERNION._serialized_end=215
# @@protoc_insertion_point(module_scope)
