# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orbita_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17orbita_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"?\n\x0fOrbitaIKRequest\x12,\n\x01q\x18\x01 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternionb\x06proto3')



_ORBITAIKREQUEST = DESCRIPTOR.message_types_by_name['OrbitaIKRequest']
OrbitaIKRequest = _reflection.GeneratedProtocolMessageType('OrbitaIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORBITAIKREQUEST,
  '__module__' : 'orbita_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.OrbitaIKRequest)
  })
_sym_db.RegisterMessage(OrbitaIKRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORBITAIKREQUEST._serialized_start=68
  _ORBITAIKREQUEST._serialized_end=131
# @@protoc_insertion_point(module_scope)
