# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: any_mobile_base_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import mobile_platform_reachy_pb2 as mobile__platform__reachy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ny_mobile_base_command.proto\x12\x13reachy.sdk.mobility\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cmobile_platform_reachy.proto\"=\n\x14ResetOdometryMessage\x12%\n\x05reset\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\x8b\x03\n\x14\x41nyMobileBaseCommand\x12;\n\x08presence\x18\x01 \x01(\x0b\x32\'.reachy.sdk.mobility.MobileBasePresenceH\x00\x12G\n\x10target_direction\x18\x02 \x01(\x0b\x32+.reachy.sdk.mobility.TargetDirectionCommandH\x00\x12<\n\x0cmode_command\x18\x03 \x01(\x0b\x32$.reachy.sdk.mobility.ZuuuModeCommandH\x00\x12\x30\n\x05go_to\x18\x04 \x01(\x0b\x32\x1f.reachy.sdk.mobility.GoToVectorH\x00\x12\x43\n\x0ereset_odometry\x18\x05 \x01(\x0b\x32).reachy.sdk.mobility.ResetOdometryMessageH\x00\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07\x63ommandb\x06proto3')



_RESETODOMETRYMESSAGE = DESCRIPTOR.message_types_by_name['ResetOdometryMessage']
_ANYMOBILEBASECOMMAND = DESCRIPTOR.message_types_by_name['AnyMobileBaseCommand']
ResetOdometryMessage = _reflection.GeneratedProtocolMessageType('ResetOdometryMessage', (_message.Message,), {
  'DESCRIPTOR' : _RESETODOMETRYMESSAGE,
  '__module__' : 'any_mobile_base_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.ResetOdometryMessage)
  })
_sym_db.RegisterMessage(ResetOdometryMessage)

AnyMobileBaseCommand = _reflection.GeneratedProtocolMessageType('AnyMobileBaseCommand', (_message.Message,), {
  'DESCRIPTOR' : _ANYMOBILEBASECOMMAND,
  '__module__' : 'any_mobile_base_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.AnyMobileBaseCommand)
  })
_sym_db.RegisterMessage(AnyMobileBaseCommand)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESETODOMETRYMESSAGE._serialized_start=146
  _RESETODOMETRYMESSAGE._serialized_end=207
  _ANYMOBILEBASECOMMAND._serialized_start=210
  _ANYMOBILEBASECOMMAND._serialized_end=605
# @@protoc_insertion_point(module_scope)
