# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fan.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tfan.proto\x12\x0ereachy.sdk.fan\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\",\n\x05\x46\x61nId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"%\n\x06\x46\x61nsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"e\n\x10\x46\x61nsStateRequest\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x16\n\x08\x46\x61nState\x12\n\n\x02on\x18\x01 \x01(\x08\"\x88\x01\n\tFansState\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12(\n\x06states\x18\x02 \x03(\x0b\x32\x18.reachy.sdk.fan.FanState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\";\n\nFanCommand\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.reachy.sdk.fan.FanId\x12\n\n\x02on\x18\x02 \x01(\x08\"j\n\x0b\x46\x61nsCommand\x12,\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.fan.FanCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x0e\x46\x61nsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x01\n\x14\x46\x61nControllerService\x12>\n\x0cGetAllFansId\x12\x16.google.protobuf.Empty\x1a\x16.reachy.sdk.fan.FansId\x12K\n\x0cGetFansState\x12 .reachy.sdk.fan.FansStateRequest\x1a\x19.reachy.sdk.fan.FansState\x12O\n\x10SendFansCommands\x12\x1b.reachy.sdk.fan.FansCommand\x1a\x1e.reachy.sdk.fan.FansCommandAckb\x06proto3')



_FANID = DESCRIPTOR.message_types_by_name['FanId']
_FANSID = DESCRIPTOR.message_types_by_name['FansId']
_FANSSTATEREQUEST = DESCRIPTOR.message_types_by_name['FansStateRequest']
_FANSTATE = DESCRIPTOR.message_types_by_name['FanState']
_FANSSTATE = DESCRIPTOR.message_types_by_name['FansState']
_FANCOMMAND = DESCRIPTOR.message_types_by_name['FanCommand']
_FANSCOMMAND = DESCRIPTOR.message_types_by_name['FansCommand']
_FANSCOMMANDACK = DESCRIPTOR.message_types_by_name['FansCommandAck']
FanId = _reflection.GeneratedProtocolMessageType('FanId', (_message.Message,), {
  'DESCRIPTOR' : _FANID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanId)
  })
_sym_db.RegisterMessage(FanId)

FansId = _reflection.GeneratedProtocolMessageType('FansId', (_message.Message,), {
  'DESCRIPTOR' : _FANSID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansId)
  })
_sym_db.RegisterMessage(FansId)

FansStateRequest = _reflection.GeneratedProtocolMessageType('FansStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATEREQUEST,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansStateRequest)
  })
_sym_db.RegisterMessage(FansStateRequest)

FanState = _reflection.GeneratedProtocolMessageType('FanState', (_message.Message,), {
  'DESCRIPTOR' : _FANSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanState)
  })
_sym_db.RegisterMessage(FanState)

FansState = _reflection.GeneratedProtocolMessageType('FansState', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansState)
  })
_sym_db.RegisterMessage(FansState)

FanCommand = _reflection.GeneratedProtocolMessageType('FanCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanCommand)
  })
_sym_db.RegisterMessage(FanCommand)

FansCommand = _reflection.GeneratedProtocolMessageType('FansCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommand)
  })
_sym_db.RegisterMessage(FansCommand)

FansCommandAck = _reflection.GeneratedProtocolMessageType('FansCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMANDACK,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommandAck)
  })
_sym_db.RegisterMessage(FansCommandAck)

_FANCONTROLLERSERVICE = DESCRIPTOR.services_by_name['FanControllerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FANID._serialized_start=91
  _FANID._serialized_end=135
  _FANSID._serialized_start=137
  _FANSID._serialized_end=174
  _FANSSTATEREQUEST._serialized_start=176
  _FANSSTATEREQUEST._serialized_end=277
  _FANSTATE._serialized_start=279
  _FANSTATE._serialized_end=301
  _FANSSTATE._serialized_start=304
  _FANSSTATE._serialized_end=440
  _FANCOMMAND._serialized_start=442
  _FANCOMMAND._serialized_end=501
  _FANSCOMMAND._serialized_start=503
  _FANSCOMMAND._serialized_end=609
  _FANSCOMMANDACK._serialized_start=611
  _FANSCOMMANDACK._serialized_end=644
  _FANCONTROLLERSERVICE._serialized_start=647
  _FANCONTROLLERSERVICE._serialized_end=891
# @@protoc_insertion_point(module_scope)
