# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: joint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bjoint.proto\x12\x10reachy.sdk.joint\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"+\n\x08PIDGains\x12\t\n\x01p\x18\x01 \x01(\x02\x12\t\n\x01i\x18\x02 \x01(\x02\x12\t\n\x01\x64\x18\x03 \x01(\x02\"\x8f\x01\n\x15\x43omplianceMarginSlope\x12\x1c\n\x14\x63w_compliance_margin\x18\x01 \x01(\x02\x12\x1d\n\x15\x63\x63w_compliance_margin\x18\x02 \x01(\x02\x12\x1b\n\x13\x63w_compliance_slope\x18\x03 \x01(\x02\x12\x1c\n\x14\x63\x63w_compliance_slope\x18\x04 \x01(\x02\"}\n\x08PIDValue\x12)\n\x03pid\x18\x01 \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDGainsH\x00\x12=\n\ncompliance\x18\x02 \x01(\x0b\x32\'.reachy.sdk.joint.ComplianceMarginSlopeH\x00\x42\x07\n\x05gains\".\n\x07JointId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"\x86\x04\n\nJointState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x03uid\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x10present_position\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\rpresent_speed\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0cpresent_load\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0btemperature\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"\x92\x01\n\x0bJointsState\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12,\n\x06states\x18\x02 \x03(\x0b\x32\x1c.reachy.sdk.joint.JointState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\x08JointsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"\xa3\x01\n\x12JointsStateRequest\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x36\n\x10requested_fields\x18\x02 \x03(\x0e\x32\x1c.reachy.sdk.joint.JointField\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x96\x01\n\x13StreamJointsRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32$.reachy.sdk.joint.JointsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa6\x02\n\x0cJointCommand\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.joint.JointId\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"p\n\rJointsCommand\x12\x30\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1e.reachy.sdk.joint.JointCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x10JointsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*\xcc\x01\n\nJointField\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x07\n\x03UID\x10\x02\x12\x14\n\x10PRESENT_POSITION\x10\x03\x12\x11\n\rPRESENT_SPEED\x10\x04\x12\x10\n\x0cPRESENT_LOAD\x10\x05\x12\x0f\n\x0bTEMPERATURE\x10\x06\x12\r\n\tCOMPLIANT\x10\x07\x12\x11\n\rGOAL_POSITION\x10\x08\x12\x0f\n\x0bSPEED_LIMIT\x10\t\x12\x10\n\x0cTORQUE_LIMIT\x10\n\x12\x07\n\x03PID\x10\x0b\x12\x07\n\x03\x41LL\x10\x0f\x32\xc2\x03\n\x0cJointService\x12\x44\n\x0eGetAllJointsId\x12\x16.google.protobuf.Empty\x1a\x1a.reachy.sdk.joint.JointsId\x12U\n\x0eGetJointsState\x12$.reachy.sdk.joint.JointsStateRequest\x1a\x1d.reachy.sdk.joint.JointsState\x12[\n\x11StreamJointsState\x12%.reachy.sdk.joint.StreamJointsRequest\x1a\x1d.reachy.sdk.joint.JointsState0\x01\x12Y\n\x12SendJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck\x12]\n\x14StreamJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck(\x01\x62\x06proto3')

_JOINTFIELD = DESCRIPTOR.enum_types_by_name['JointField']
JointField = enum_type_wrapper.EnumTypeWrapper(_JOINTFIELD)
NONE = 0
NAME = 1
UID = 2
PRESENT_POSITION = 3
PRESENT_SPEED = 4
PRESENT_LOAD = 5
TEMPERATURE = 6
COMPLIANT = 7
GOAL_POSITION = 8
SPEED_LIMIT = 9
TORQUE_LIMIT = 10
PID = 11
ALL = 15


_PIDGAINS = DESCRIPTOR.message_types_by_name['PIDGains']
_COMPLIANCEMARGINSLOPE = DESCRIPTOR.message_types_by_name['ComplianceMarginSlope']
_PIDVALUE = DESCRIPTOR.message_types_by_name['PIDValue']
_JOINTID = DESCRIPTOR.message_types_by_name['JointId']
_JOINTSTATE = DESCRIPTOR.message_types_by_name['JointState']
_JOINTSSTATE = DESCRIPTOR.message_types_by_name['JointsState']
_JOINTSID = DESCRIPTOR.message_types_by_name['JointsId']
_JOINTSSTATEREQUEST = DESCRIPTOR.message_types_by_name['JointsStateRequest']
_STREAMJOINTSREQUEST = DESCRIPTOR.message_types_by_name['StreamJointsRequest']
_JOINTCOMMAND = DESCRIPTOR.message_types_by_name['JointCommand']
_JOINTSCOMMAND = DESCRIPTOR.message_types_by_name['JointsCommand']
_JOINTSCOMMANDACK = DESCRIPTOR.message_types_by_name['JointsCommandAck']
PIDGains = _reflection.GeneratedProtocolMessageType('PIDGains', (_message.Message,), {
  'DESCRIPTOR' : _PIDGAINS,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDGains)
  })
_sym_db.RegisterMessage(PIDGains)

ComplianceMarginSlope = _reflection.GeneratedProtocolMessageType('ComplianceMarginSlope', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEMARGINSLOPE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ComplianceMarginSlope)
  })
_sym_db.RegisterMessage(ComplianceMarginSlope)

PIDValue = _reflection.GeneratedProtocolMessageType('PIDValue', (_message.Message,), {
  'DESCRIPTOR' : _PIDVALUE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDValue)
  })
_sym_db.RegisterMessage(PIDValue)

JointId = _reflection.GeneratedProtocolMessageType('JointId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointId)
  })
_sym_db.RegisterMessage(JointId)

JointState = _reflection.GeneratedProtocolMessageType('JointState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointState)
  })
_sym_db.RegisterMessage(JointState)

JointsState = _reflection.GeneratedProtocolMessageType('JointsState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsState)
  })
_sym_db.RegisterMessage(JointsState)

JointsId = _reflection.GeneratedProtocolMessageType('JointsId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsId)
  })
_sym_db.RegisterMessage(JointsId)

JointsStateRequest = _reflection.GeneratedProtocolMessageType('JointsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATEREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsStateRequest)
  })
_sym_db.RegisterMessage(JointsStateRequest)

StreamJointsRequest = _reflection.GeneratedProtocolMessageType('StreamJointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMJOINTSREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamJointsRequest)
  })
_sym_db.RegisterMessage(StreamJointsRequest)

JointCommand = _reflection.GeneratedProtocolMessageType('JointCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointCommand)
  })
_sym_db.RegisterMessage(JointCommand)

JointsCommand = _reflection.GeneratedProtocolMessageType('JointsCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommand)
  })
_sym_db.RegisterMessage(JointsCommand)

JointsCommandAck = _reflection.GeneratedProtocolMessageType('JointsCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMANDACK,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommandAck)
  })
_sym_db.RegisterMessage(JointsCommandAck)

_JOINTSERVICE = DESCRIPTOR.services_by_name['JointService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOINTFIELD._serialized_start=1972
  _JOINTFIELD._serialized_end=2176
  _PIDGAINS._serialized_start=127
  _PIDGAINS._serialized_end=170
  _COMPLIANCEMARGINSLOPE._serialized_start=173
  _COMPLIANCEMARGINSLOPE._serialized_end=316
  _PIDVALUE._serialized_start=318
  _PIDVALUE._serialized_end=443
  _JOINTID._serialized_start=445
  _JOINTID._serialized_end=491
  _JOINTSTATE._serialized_start=494
  _JOINTSTATE._serialized_end=1012
  _JOINTSSTATE._serialized_start=1015
  _JOINTSSTATE._serialized_end=1161
  _JOINTSID._serialized_start=1163
  _JOINTSID._serialized_end=1202
  _JOINTSSTATEREQUEST._serialized_start=1205
  _JOINTSSTATEREQUEST._serialized_end=1368
  _STREAMJOINTSREQUEST._serialized_start=1371
  _STREAMJOINTSREQUEST._serialized_end=1521
  _JOINTCOMMAND._serialized_start=1524
  _JOINTCOMMAND._serialized_end=1818
  _JOINTSCOMMAND._serialized_start=1820
  _JOINTSCOMMAND._serialized_end=1932
  _JOINTSCOMMANDACK._serialized_start=1934
  _JOINTSCOMMANDACK._serialized_end=1969
  _JOINTSERVICE._serialized_start=2179
  _JOINTSERVICE._serialized_end=2629
# @@protoc_insertion_point(module_scope)
