# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10trajectory.proto\x12\x15reachy.sdk.trajectory\x1a\x1egoogle/protobuf/wrappers.proto\"\xd9\x01\n\x11TrajectoryRequest\x12\x36\n\x11starting_position\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x34\n\x0ftarget_position\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x02\x64t\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"+\n\nTrajectory\x12\x11\n\tpositions\x18\x01 \x03(\x01\x12\n\n\x02\x64t\x18\x02 \x01(\x01\x32\x80\x01\n\x11TrajectoryService\x12k\n\x1c\x43omputeMinimumJerkTrajectory\x12(.reachy.sdk.trajectory.TrajectoryRequest\x1a!.reachy.sdk.trajectory.Trajectoryb\x06proto3')



_TRAJECTORYREQUEST = DESCRIPTOR.message_types_by_name['TrajectoryRequest']
_TRAJECTORY = DESCRIPTOR.message_types_by_name['Trajectory']
TrajectoryRequest = _reflection.GeneratedProtocolMessageType('TrajectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYREQUEST,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.TrajectoryRequest)
  })
_sym_db.RegisterMessage(TrajectoryRequest)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

_TRAJECTORYSERVICE = DESCRIPTOR.services_by_name['TrajectoryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAJECTORYREQUEST._serialized_start=76
  _TRAJECTORYREQUEST._serialized_end=293
  _TRAJECTORY._serialized_start=295
  _TRAJECTORY._serialized_end=338
  _TRAJECTORYSERVICE._serialized_start=341
  _TRAJECTORYSERVICE._serialized_end=469
# @@protoc_insertion_point(module_scope)
