# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_reachy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63\x61mera_reachy.proto\x12\x11reachy.sdk.camera\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"1\n\x06\x43\x61mera\x12\'\n\x02id\x18\x01 \x01(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"3\n\x07\x43\x61meras\x12(\n\x03ids\x18\x01 \x03(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"9\n\x0cImageRequest\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\"F\n\x12StreamImageRequest\x12\x30\n\x07request\x18\x01 \x01(\x0b\x32\x1f.reachy.sdk.camera.ImageRequest\"\x1a\n\tZoomSpeed\x12\r\n\x05speed\x18\x01 \x01(\r\"\x0c\n\nZoomHoming\"E\n\tZoomLevel\x12\x38\n\x05level\x18\x01 \x01(\x0e\x32).reachy.sdk.camera.ZoomLevelPossibilities\"!\n\x0eZoomCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xea\x01\n\x0bZoomCommand\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\x12\x37\n\x0ehoming_command\x18\x02 \x01(\x0b\x32\x1d.reachy.sdk.camera.ZoomHomingH\x00\x12\x35\n\rspeed_command\x18\x03 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomSpeedH\x00\x12\x35\n\rlevel_command\x18\x04 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomLevelH\x00\x42\t\n\x07\x63ommand\"\xda\x01\n\x10ZoomFocusMessage\x12\x30\n\nleft_focus\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\tleft_zoom\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bright_focus\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x30\n\nright_zoom\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value*\x1f\n\x08\x43\x61meraId\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01*>\n\x16ZoomLevelPossibilities\x12\x08\n\x04ZERO\x10\x00\x12\x06\n\x02IN\x10\x01\x12\t\n\x05INTER\x10\x02\x12\x07\n\x03OUT\x10\x03\x32\xd4\x05\n\rCameraService\x12\x45\n\x08GetImage\x12\x1f.reachy.sdk.camera.ImageRequest\x1a\x18.reachy.sdk.camera.Image\x12P\n\x0bStreamImage\x12%.reachy.sdk.camera.StreamImageRequest\x1a\x18.reachy.sdk.camera.Image0\x01\x12G\n\x0cGetZoomLevel\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomLevel\x12G\n\x0cGetZoomSpeed\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomSpeed\x12T\n\x0fSendZoomCommand\x12\x1e.reachy.sdk.camera.ZoomCommand\x1a!.reachy.sdk.camera.ZoomCommandAck\x12K\n\x0cGetZoomFocus\x12\x16.google.protobuf.Empty\x1a#.reachy.sdk.camera.ZoomFocusMessage\x12V\n\x0cSetZoomFocus\x12#.reachy.sdk.camera.ZoomFocusMessage\x1a!.reachy.sdk.camera.ZoomCommandAck\x12N\n\x0eStartAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAck\x12M\n\rStopAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAckb\x06proto3')

_CAMERAID = DESCRIPTOR.enum_types_by_name['CameraId']
CameraId = enum_type_wrapper.EnumTypeWrapper(_CAMERAID)
_ZOOMLEVELPOSSIBILITIES = DESCRIPTOR.enum_types_by_name['ZoomLevelPossibilities']
ZoomLevelPossibilities = enum_type_wrapper.EnumTypeWrapper(_ZOOMLEVELPOSSIBILITIES)
LEFT = 0
RIGHT = 1
ZERO = 0
IN = 1
INTER = 2
OUT = 3


_IMAGE = DESCRIPTOR.message_types_by_name['Image']
_CAMERA = DESCRIPTOR.message_types_by_name['Camera']
_CAMERAS = DESCRIPTOR.message_types_by_name['Cameras']
_IMAGEREQUEST = DESCRIPTOR.message_types_by_name['ImageRequest']
_STREAMIMAGEREQUEST = DESCRIPTOR.message_types_by_name['StreamImageRequest']
_ZOOMSPEED = DESCRIPTOR.message_types_by_name['ZoomSpeed']
_ZOOMHOMING = DESCRIPTOR.message_types_by_name['ZoomHoming']
_ZOOMLEVEL = DESCRIPTOR.message_types_by_name['ZoomLevel']
_ZOOMCOMMANDACK = DESCRIPTOR.message_types_by_name['ZoomCommandAck']
_ZOOMCOMMAND = DESCRIPTOR.message_types_by_name['ZoomCommand']
_ZOOMFOCUSMESSAGE = DESCRIPTOR.message_types_by_name['ZoomFocusMessage']
Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Image)
  })
_sym_db.RegisterMessage(Image)

Camera = _reflection.GeneratedProtocolMessageType('Camera', (_message.Message,), {
  'DESCRIPTOR' : _CAMERA,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Camera)
  })
_sym_db.RegisterMessage(Camera)

Cameras = _reflection.GeneratedProtocolMessageType('Cameras', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAS,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Cameras)
  })
_sym_db.RegisterMessage(Cameras)

ImageRequest = _reflection.GeneratedProtocolMessageType('ImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ImageRequest)
  })
_sym_db.RegisterMessage(ImageRequest)

StreamImageRequest = _reflection.GeneratedProtocolMessageType('StreamImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMIMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.StreamImageRequest)
  })
_sym_db.RegisterMessage(StreamImageRequest)

ZoomSpeed = _reflection.GeneratedProtocolMessageType('ZoomSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMSPEED,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomSpeed)
  })
_sym_db.RegisterMessage(ZoomSpeed)

ZoomHoming = _reflection.GeneratedProtocolMessageType('ZoomHoming', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMHOMING,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomHoming)
  })
_sym_db.RegisterMessage(ZoomHoming)

ZoomLevel = _reflection.GeneratedProtocolMessageType('ZoomLevel', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMLEVEL,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomLevel)
  })
_sym_db.RegisterMessage(ZoomLevel)

ZoomCommandAck = _reflection.GeneratedProtocolMessageType('ZoomCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMANDACK,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommandAck)
  })
_sym_db.RegisterMessage(ZoomCommandAck)

ZoomCommand = _reflection.GeneratedProtocolMessageType('ZoomCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMAND,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommand)
  })
_sym_db.RegisterMessage(ZoomCommand)

ZoomFocusMessage = _reflection.GeneratedProtocolMessageType('ZoomFocusMessage', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMFOCUSMESSAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomFocusMessage)
  })
_sym_db.RegisterMessage(ZoomFocusMessage)

_CAMERASERVICE = DESCRIPTOR.services_by_name['CameraService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CAMERAID._serialized_start=967
  _CAMERAID._serialized_end=998
  _ZOOMLEVELPOSSIBILITIES._serialized_start=1000
  _ZOOMLEVELPOSSIBILITIES._serialized_end=1062
  _IMAGE._serialized_start=103
  _IMAGE._serialized_end=124
  _CAMERA._serialized_start=126
  _CAMERA._serialized_end=175
  _CAMERAS._serialized_start=177
  _CAMERAS._serialized_end=228
  _IMAGEREQUEST._serialized_start=230
  _IMAGEREQUEST._serialized_end=287
  _STREAMIMAGEREQUEST._serialized_start=289
  _STREAMIMAGEREQUEST._serialized_end=359
  _ZOOMSPEED._serialized_start=361
  _ZOOMSPEED._serialized_end=387
  _ZOOMHOMING._serialized_start=389
  _ZOOMHOMING._serialized_end=401
  _ZOOMLEVEL._serialized_start=403
  _ZOOMLEVEL._serialized_end=472
  _ZOOMCOMMANDACK._serialized_start=474
  _ZOOMCOMMANDACK._serialized_end=507
  _ZOOMCOMMAND._serialized_start=510
  _ZOOMCOMMAND._serialized_end=744
  _ZOOMFOCUSMESSAGE._serialized_start=747
  _ZOOMFOCUSMESSAGE._serialized_end=965
  _CAMERASERVICE._serialized_start=1065
  _CAMERASERVICE._serialized_end=1789
# @@protoc_insertion_point(module_scope)
