# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: head_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15head_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"o\n\rHeadIKRequest\x12,\n\x01q\x18\x01 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternion\x12\x30\n\x02q0\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"L\n\rHeadFKRequest\x12;\n\rneck_position\x18\x01 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"O\n\x0eHeadFKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12,\n\x01q\x18\x02 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternion\"^\n\x0eHeadIKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12;\n\rneck_position\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition2\xcc\x01\n\x0eHeadKinematics\x12\\\n\rComputeHeadFK\x12$.reachy.sdk.kinematics.HeadFKRequest\x1a%.reachy.sdk.kinematics.HeadFKSolution\x12\\\n\rComputeHeadIK\x12$.reachy.sdk.kinematics.HeadIKRequest\x1a%.reachy.sdk.kinematics.HeadIKSolutionb\x06proto3')



_HEADIKREQUEST = DESCRIPTOR.message_types_by_name['HeadIKRequest']
_HEADFKREQUEST = DESCRIPTOR.message_types_by_name['HeadFKRequest']
_HEADFKSOLUTION = DESCRIPTOR.message_types_by_name['HeadFKSolution']
_HEADIKSOLUTION = DESCRIPTOR.message_types_by_name['HeadIKSolution']
HeadIKRequest = _reflection.GeneratedProtocolMessageType('HeadIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEADIKREQUEST,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadIKRequest)
  })
_sym_db.RegisterMessage(HeadIKRequest)

HeadFKRequest = _reflection.GeneratedProtocolMessageType('HeadFKRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEADFKREQUEST,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadFKRequest)
  })
_sym_db.RegisterMessage(HeadFKRequest)

HeadFKSolution = _reflection.GeneratedProtocolMessageType('HeadFKSolution', (_message.Message,), {
  'DESCRIPTOR' : _HEADFKSOLUTION,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadFKSolution)
  })
_sym_db.RegisterMessage(HeadFKSolution)

HeadIKSolution = _reflection.GeneratedProtocolMessageType('HeadIKSolution', (_message.Message,), {
  'DESCRIPTOR' : _HEADIKSOLUTION,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadIKSolution)
  })
_sym_db.RegisterMessage(HeadIKSolution)

_HEADKINEMATICS = DESCRIPTOR.services_by_name['HeadKinematics']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEADIKREQUEST._serialized_start=66
  _HEADIKREQUEST._serialized_end=177
  _HEADFKREQUEST._serialized_start=179
  _HEADFKREQUEST._serialized_end=255
  _HEADFKSOLUTION._serialized_start=257
  _HEADFKSOLUTION._serialized_end=336
  _HEADIKSOLUTION._serialized_start=338
  _HEADIKSOLUTION._serialized_end=432
  _HEADKINEMATICS._serialized_start=435
  _HEADKINEMATICS._serialized_end=639
# @@protoc_insertion_point(module_scope)
