# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csensor.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"/\n\x08SensorId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"(\n\tSensorsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"!\n\x10\x46orceSensorState\x12\r\n\x05\x66orce\x18\x01 \x01(\x02\"X\n\x0bSensorState\x12@\n\x12\x66orce_sensor_state\x18\x01 \x01(\x0b\x32\".reachy.sdk.joint.ForceSensorStateH\x00\x42\x07\n\x05state\"\x95\x01\n\x0cSensorsState\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.reachy.sdk.joint.SensorState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n\x13SensorsStateRequest\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x19StreamSensorsStateRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.reachy.sdk.joint.SensorsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x32\x9b\x02\n\rSensorService\x12K\n\x14GetAllForceSensorsId\x12\x16.google.protobuf.Empty\x1a\x1b.reachy.sdk.joint.SensorsId\x12X\n\x0fGetSensorsState\x12%.reachy.sdk.joint.SensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState\x12\x63\n\x12StreamSensorStates\x12+.reachy.sdk.joint.StreamSensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState0\x01\x62\x06proto3')



_SENSORID = DESCRIPTOR.message_types_by_name['SensorId']
_SENSORSID = DESCRIPTOR.message_types_by_name['SensorsId']
_FORCESENSORSTATE = DESCRIPTOR.message_types_by_name['ForceSensorState']
_SENSORSTATE = DESCRIPTOR.message_types_by_name['SensorState']
_SENSORSSTATE = DESCRIPTOR.message_types_by_name['SensorsState']
_SENSORSSTATEREQUEST = DESCRIPTOR.message_types_by_name['SensorsStateRequest']
_STREAMSENSORSSTATEREQUEST = DESCRIPTOR.message_types_by_name['StreamSensorsStateRequest']
SensorId = _reflection.GeneratedProtocolMessageType('SensorId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorId)
  })
_sym_db.RegisterMessage(SensorId)

SensorsId = _reflection.GeneratedProtocolMessageType('SensorsId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsId)
  })
_sym_db.RegisterMessage(SensorsId)

ForceSensorState = _reflection.GeneratedProtocolMessageType('ForceSensorState', (_message.Message,), {
  'DESCRIPTOR' : _FORCESENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ForceSensorState)
  })
_sym_db.RegisterMessage(ForceSensorState)

SensorState = _reflection.GeneratedProtocolMessageType('SensorState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorState)
  })
_sym_db.RegisterMessage(SensorState)

SensorsState = _reflection.GeneratedProtocolMessageType('SensorsState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsState)
  })
_sym_db.RegisterMessage(SensorsState)

SensorsStateRequest = _reflection.GeneratedProtocolMessageType('SensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsStateRequest)
  })
_sym_db.RegisterMessage(SensorsStateRequest)

StreamSensorsStateRequest = _reflection.GeneratedProtocolMessageType('StreamSensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamSensorsStateRequest)
  })
_sym_db.RegisterMessage(StreamSensorsStateRequest)

_SENSORSERVICE = DESCRIPTOR.services_by_name['SensorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SENSORID._serialized_start=96
  _SENSORID._serialized_end=143
  _SENSORSID._serialized_start=145
  _SENSORSID._serialized_end=185
  _FORCESENSORSTATE._serialized_start=187
  _FORCESENSORSTATE._serialized_end=220
  _SENSORSTATE._serialized_start=222
  _SENSORSTATE._serialized_end=310
  _SENSORSSTATE._serialized_start=313
  _SENSORSSTATE._serialized_end=462
  _SENSORSSTATEREQUEST._serialized_start=464
  _SENSORSSTATEREQUEST._serialized_end=573
  _STREAMSENSORSSTATEREQUEST._serialized_start=575
  _STREAMSENSORSSTATEREQUEST._serialized_end=685
  _SENSORSERVICE._serialized_start=688
  _SENSORSERVICE._serialized_end=971
# @@protoc_insertion_point(module_scope)
