# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exo_arm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rexo_arm.proto\x12\x12reachy.sdk.exo_arm\x1a\x1egoogle/protobuf/wrappers.proto\"e\n\x0c\x45lbowTorques\x12*\n\x05right\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12)\n\x04left\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Valueb\x06proto3')



_ELBOWTORQUES = DESCRIPTOR.message_types_by_name['ElbowTorques']
ElbowTorques = _reflection.GeneratedProtocolMessageType('ElbowTorques', (_message.Message,), {
  'DESCRIPTOR' : _ELBOWTORQUES,
  '__module__' : 'exo_arm_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.exo_arm.ElbowTorques)
  })
_sym_db.RegisterMessage(ElbowTorques)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ELBOWTORQUES._serialized_start=69
  _ELBOWTORQUES._serialized_end=170
# @@protoc_insertion_point(module_scope)
