# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: any_joint_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import fullbody_cartesian_command_pb2 as fullbody__cartesian__command__pb2
import joint_pb2 as joint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ny_joint_command.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fullbody_cartesian_command.proto\x1a\x0bjoint.proto\"\xc5\x01\n\x10\x41nyJointsCommand\x12\x44\n\tfull_body\x18\x01 \x01(\x0b\x32/.reachy.sdk.kinematics.FullBodyCartesianCommandH\x00\x12\x31\n\x06joints\x18\x03 \x01(\x0b\x32\x1f.reachy.sdk.joint.JointsCommandH\x00\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07\x63ommandb\x06proto3')



_ANYJOINTSCOMMAND = DESCRIPTOR.message_types_by_name['AnyJointsCommand']
AnyJointsCommand = _reflection.GeneratedProtocolMessageType('AnyJointsCommand', (_message.Message,), {
  'DESCRIPTOR' : _ANYJOINTSCOMMAND,
  '__module__' : 'any_joint_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.AnyJointsCommand)
  })
_sym_db.RegisterMessage(AnyJointsCommand)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANYJOINTSCOMMAND._serialized_start=126
  _ANYJOINTSCOMMAND._serialized_end=323
# @@protoc_insertion_point(module_scope)
