# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fullbody_cartesian_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import arm_kinematics_pb2 as arm__kinematics__pb2
import head_kinematics_pb2 as head__kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n fullbody_cartesian_command.proto\x12\x15reachy.sdk.kinematics\x1a\x14\x61rm_kinematics.proto\x1a\x15head_kinematics.proto\"\x80\x01\n\x1b\x46ullBodyCartesianCommandAck\x12 \n\x18left_arm_command_success\x18\x01 \x01(\x08\x12!\n\x19right_arm_command_success\x18\x02 \x01(\x08\x12\x1c\n\x14head_command_success\x18\x03 \x01(\x08\"\xbd\x01\n\x18\x46ullBodyCartesianCommand\x12\x35\n\x08left_arm\x18\x01 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x36\n\tright_arm\x18\x02 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x32\n\x04head\x18\x03 \x01(\x0b\x32$.reachy.sdk.kinematics.HeadIKRequest2\xb3\x02\n\x1f\x46ullBodyCartesianCommandService\x12\x84\x01\n\x1dSendFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck\x12\x88\x01\n\x1fStreamFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck(\x01\x62\x06proto3')



_FULLBODYCARTESIANCOMMANDACK = DESCRIPTOR.message_types_by_name['FullBodyCartesianCommandAck']
_FULLBODYCARTESIANCOMMAND = DESCRIPTOR.message_types_by_name['FullBodyCartesianCommand']
FullBodyCartesianCommandAck = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMANDACK,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommandAck)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommandAck)

FullBodyCartesianCommand = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommand', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMAND,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommand)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommand)

_FULLBODYCARTESIANCOMMANDSERVICE = DESCRIPTOR.services_by_name['FullBodyCartesianCommandService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FULLBODYCARTESIANCOMMANDACK._serialized_start=105
  _FULLBODYCARTESIANCOMMANDACK._serialized_end=233
  _FULLBODYCARTESIANCOMMAND._serialized_start=236
  _FULLBODYCARTESIANCOMMAND._serialized_end=425
  _FULLBODYCARTESIANCOMMANDSERVICE._serialized_start=428
  _FULLBODYCARTESIANCOMMANDSERVICE._serialized_end=735
# @@protoc_insertion_point(module_scope)
