# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: restart_signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14restart_signal.proto\x12\x12reachy.sdk.restart\"9\n\nRestartCmd\x12+\n\x03\x63md\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.restart.SignalType\"#\n\x10RestartSignalAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*#\n\nSignalType\x12\x0b\n\x07RESTART\x10\x00\x12\x08\n\x04STOP\x10\x01\x32k\n\x0eRestartService\x12Y\n\x11SendRestartSignal\x12\x1e.reachy.sdk.restart.RestartCmd\x1a$.reachy.sdk.restart.RestartSignalAckb\x06proto3')

_SIGNALTYPE = DESCRIPTOR.enum_types_by_name['SignalType']
SignalType = enum_type_wrapper.EnumTypeWrapper(_SIGNALTYPE)
RESTART = 0
STOP = 1


_RESTARTCMD = DESCRIPTOR.message_types_by_name['RestartCmd']
_RESTARTSIGNALACK = DESCRIPTOR.message_types_by_name['RestartSignalAck']
RestartCmd = _reflection.GeneratedProtocolMessageType('RestartCmd', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTCMD,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartCmd)
  })
_sym_db.RegisterMessage(RestartCmd)

RestartSignalAck = _reflection.GeneratedProtocolMessageType('RestartSignalAck', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTSIGNALACK,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartSignalAck)
  })
_sym_db.RegisterMessage(RestartSignalAck)

_RESTARTSERVICE = DESCRIPTOR.services_by_name['RestartService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SIGNALTYPE._serialized_start=140
  _SIGNALTYPE._serialized_end=175
  _RESTARTCMD._serialized_start=44
  _RESTARTCMD._serialized_end=101
  _RESTARTSIGNALACK._serialized_start=103
  _RESTARTSIGNALACK._serialized_end=138
  _RESTARTSERVICE._serialized_start=177
  _RESTARTSERVICE._serialized_end=284
# @@protoc_insertion_point(module_scope)
