# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import sensor_pb2 as sensor__pb2


class SensorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllForceSensorsId = channel.unary_unary(
                '/reachy.sdk.joint.SensorService/GetAllForceSensorsId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=sensor__pb2.SensorsId.FromString,
                )
        self.GetSensorsState = channel.unary_unary(
                '/reachy.sdk.joint.SensorService/GetSensorsState',
                request_serializer=sensor__pb2.SensorsStateRequest.SerializeToString,
                response_deserializer=sensor__pb2.SensorsState.FromString,
                )
        self.StreamSensorStates = channel.unary_stream(
                '/reachy.sdk.joint.SensorService/StreamSensorStates',
                request_serializer=sensor__pb2.StreamSensorsStateRequest.SerializeToString,
                response_deserializer=sensor__pb2.SensorsState.FromString,
                )


class SensorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllForceSensorsId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSensorsState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSensorStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SensorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAllForceSensorsId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllForceSensorsId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=sensor__pb2.SensorsId.SerializeToString,
            ),
            'GetSensorsState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSensorsState,
                    request_deserializer=sensor__pb2.SensorsStateRequest.FromString,
                    response_serializer=sensor__pb2.SensorsState.SerializeToString,
            ),
            'StreamSensorStates': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamSensorStates,
                    request_deserializer=sensor__pb2.StreamSensorsStateRequest.FromString,
                    response_serializer=sensor__pb2.SensorsState.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.joint.SensorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SensorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllForceSensorsId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.SensorService/GetAllForceSensorsId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            sensor__pb2.SensorsId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSensorsState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.SensorService/GetSensorsState',
            sensor__pb2.SensorsStateRequest.SerializeToString,
            sensor__pb2.SensorsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSensorStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/reachy.sdk.joint.SensorService/StreamSensorStates',
            sensor__pb2.StreamSensorsStateRequest.SerializeToString,
            sensor__pb2.SensorsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
